@@ -332,7 +332,7 @@ class Base(Controller):
         help='All Github related operations',
         arguments=[
              (['action'],{
-                "help" : "To show one of {forks}.",
+                "help" : "To show one of {forks, contrib}.",
                 "action" : "store"
             }),
             (['-url'],{
@@ -342,9 +342,13 @@ class Base(Controller):
         ]
     )
     def gh(self):
-        from ..ext.github import find_forks
         if self.app.pargs.action=='forks':
+            from ..ext.github import find_forks
             print(find_forks(self.app.pargs.url))
+        if self.app.pargs.action=='contrib':
+            from ..ext.github import find_contributors
+            print(find_contributors(self.app.pargs.url))
+
 
     @ex(
         help='Manage TODOs using Google Keep',
